@@ -376,7 +376,7 @@ void check_no_worker_running(char* worker_logfile) {
 /* main tests */
 int main (int argc, char **argv, char **env) {
     argc = argc; argv = argv; env  = env;
-    int status, chld, rc;
+    int status, chld;
     int tests = 123;
     int rrc;
     char cmd[150];
@@ -569,8 +569,8 @@ int main (int argc, char **argv, char **env) {
     /* cleanup */
     free(result);
     free(error);
-    free_client(&client);
-    free_worker(&worker);
+    gm_free_client(&client);
+    gm_free_worker(&worker);
 
     /* shutdown gearmand */
     kill(gearmand_pid, SIGTERM);
